@@ -24,6 +24,7 @@
 
 #include <libgssdp/gssdp-client.h>
 #include <libsoup/soup-server.h>
+#include <libsoup/soup-session.h>
 
 G_BEGIN_DECLS
 
@@ -53,6 +54,12 @@ gupnp_context_get_type (void) G_GNUC_CONST;
 
 typedef struct _GUPnPContextPrivate GUPnPContextPrivate;
 
+/**
+ * GUPnPContext:
+ *
+ * This struct contains private data only, and should be accessed using the
+ * functions below.
+ */
 typedef struct {
         GSSDPClient parent;
 
@@ -84,6 +91,9 @@ gupnp_context_get_port                 (GUPnPContext *context);
 SoupServer *
 gupnp_context_get_server               (GUPnPContext *context);
 
+SoupSession *
+gupnp_context_get_session              (GUPnPContext *context);
+
 void
 gupnp_context_set_subscription_timeout (GUPnPContext *context,
                                         guint         timeout);
