@@ -584,15 +584,15 @@ gupnp_service_info_get_introspection (GUPnPServiceInfo *info,
 
         status = soup_session_send_message (session, msg);
         if (!SOUP_STATUS_IS_SUCCESSFUL (status)) {
-                set_server_error (error, msg);
+                _gupnp_error_set_server_error (error, msg);
 
                 g_object_unref (msg);
 
                 return NULL;
         }
 
-        scpd = xmlParseMemory (msg->response_body->data,
-                               msg->response_body->length);
+        scpd = xmlRecoverMemory (msg->response_body->data,
+                                 msg->response_body->length);
 
         g_object_unref (msg);
 
@@ -632,8 +632,8 @@ got_scpd_url (SoupSession    *session,
         if (SOUP_STATUS_IS_SUCCESSFUL (msg->status_code)) {
                 xmlDoc *scpd;
 
-                scpd = xmlParseMemory (msg->response_body->data,
-                                       msg->response_body->length);
+                scpd = xmlRecoverMemory (msg->response_body->data,
+                                         msg->response_body->length);
                 if (scpd) {
                         introspection = gupnp_service_introspection_new (scpd);
 
@@ -647,7 +647,7 @@ got_scpd_url (SoupSession    *session,
                                          "Could not parse SCPD");
                 }
         } else
-                error = new_server_error (msg);
+                error = _gupnp_error_new_server_error (msg);
 
         data->info->priv->pending_gets =
                 g_list_remove (data->info->priv->pending_gets, data);
